From 7e48bdf4e952f7b700e64e4cd8cb190bfc630ef9 Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Wed, 31 Oct 2012 07:42:05 -0400
Subject: [PATCH] Fixed: Follow-up to commit r3623 - entered all missing german and english entries for datalog status - excluded some more tables from status display - inserted the info-display code to the relevant templates
---
server/plugins-available/apache2_plugin.inc.php | 63 +++++++++++++++++--------------
1 files changed, 35 insertions(+), 28 deletions(-)
diff --git a/server/plugins-available/apache2_plugin.inc.php b/server/plugins-available/apache2_plugin.inc.php
index ae5ce80..9cffcc1 100644
--- a/server/plugins-available/apache2_plugin.inc.php
+++ b/server/plugins-available/apache2_plugin.inc.php
@@ -115,8 +115,8 @@
$csr_file = $ssl_dir.'/'.$domain.'.csr';
$crt_file = $ssl_dir.'/'.$domain.'.crt';
- //* Create a SSL Certificate
- if($data['new']['ssl_action'] == 'create') {
+ //* Create a SSL Certificate, but only if this is not a mirror server.
+ if($data['new']['ssl_action'] == 'create' && $conf['mirror_server_id'] == 0) {
$this->ssl_certificate_changed = true;
@@ -1098,6 +1098,7 @@
$tpl->setVar('fastcgi_starter_path',$fastcgi_starter_path);
$tpl->setVar('fastcgi_starter_script',$fastcgi_config['fastcgi_starter_script'].($data['new']['type'] == 'vhostsubdomain' ? '_web' . $data['new']['domain_id'] : ''));
$tpl->setVar('fastcgi_config_syntax',$fastcgi_config['fastcgi_config_syntax']);
+ $tpl->setVar('fastcgi_max_requests',$fastcgi_config['fastcgi_max_requests']);
} else {
//remove the php fastgi starter script if available
@@ -1354,7 +1355,7 @@
$app->system->web_folder_protection($data['new']['document_root'],false);
$app->system->file_put_contents($data['new']['document_root'].'/.htpasswd_stats',$htp_file);
$app->system->web_folder_protection($data['new']['document_root'],true);
- $app->system->chmod($data['new']['document_root'].'/.htpasswd_stats',0755);
+ $app->system->chmod($data['new']['document_root'].'/.htpasswd_stats',0750);
unset($htp_file);
}
}
@@ -1715,8 +1716,8 @@
//* Create empty .htpasswd file, if it does not exist
if(!is_file($folder_path.'.htpasswd')) {
- touch($folder_path.'.htpasswd');
- $app->system->chmod($folder_path.'.htpasswd',0755);
+ $app->system->touch($folder_path.'.htpasswd');
+ $app->system->chmod($folder_path.'.htpasswd',0750);
$app->system->chown($folder_path.'.htpasswd',$website['system_user']);
$app->system->chgrp($folder_path.'.htpasswd',$website['system_group']);
$app->log('Created file '.$folder_path.'.htpasswd',LOGLEVEL_DEBUG);
@@ -1770,7 +1771,7 @@
unset($old_content);
$app->system->file_put_contents($folder_path.'.htaccess',$ht_file);
- $app->system->chmod($folder_path.'.htaccess',0755);
+ $app->system->chmod($folder_path.'.htaccess',0750);
$app->system->chown($folder_path.'.htaccess',$website['system_user']);
$app->system->chgrp($folder_path.'.htaccess',$website['system_group']);
$app->log('Created/modified file '.$folder_path.'.htaccess',LOGLEVEL_DEBUG);
@@ -1932,7 +1933,7 @@
}
$app->system->file_put_contents($new_folder_path.'.htaccess',$ht_file);
- $app->system->chmod($new_folder_path.'.htaccess',0755);
+ $app->system->chmod($new_folder_path.'.htaccess',0750);
$app->system->chown($new_folder_path.'.htaccess',$website['system_user']);
$app->system->chgrp($new_folder_path.'.htaccess',$website['system_group']);
$app->log('Created/modified file '.$new_folder_path.'.htaccess',LOGLEVEL_DEBUG);
@@ -2118,6 +2119,8 @@
* @param string $pwd The password-hash of the user
*/
private function _writeHtDigestFile($filename, $username, $authname, $pwdhash ) {
+ global $app;
+
$changed = false;
if(is_file($filename) && !is_link($filename)) {
$in = fopen($filename, 'r');
@@ -2196,7 +2199,7 @@
$files = @scandir($webdavRoot);
if(is_array($files)) {
foreach($files as $file) {
- if (substr($file, strlen($file) - strlen('.htdigest')) == '.htdigest' && preg_match("[a-zA-Z0-9\-_\.]",$file)) {
+ if (substr($file, strlen($file) - strlen('.htdigest')) == '.htdigest' && preg_match("/^[a-zA-Z0-9\-_\.]*$/",$file)) {
/*
* found a htdigest - file, so add it to webdav
*/
@@ -2381,27 +2384,31 @@
$ini_settings = explode("\n", $custom_php_ini_settings);
if(is_array($ini_settings) && !empty($ini_settings)){
foreach($ini_settings as $ini_setting){
- list($key, $value) = explode('=', $ini_setting);
- if($value){
- $value = trim($value);
- $key = trim($key);
- switch (strtolower($value)) {
- case '0':
- // PHP-FPM might complain about invalid boolean value if you use 0
- $value = 'off';
- case '1':
- case 'on':
- case 'off':
- case 'true':
- case 'false':
- case 'yes':
- case 'no':
- $final_php_ini_settings[] = array('ini_setting' => 'php_admin_flag['.$key.'] = '.$value);
- break;
- default:
- $final_php_ini_settings[] = array('ini_setting' => 'php_admin_value['.$key.'] = '.$value);
- }
+ $ini_setting = trim($ini_setting);
+ if(substr($ini_setting,0,1) == ';') continue;
+ if(substr($ini_setting,0,1) == '#') continue;
+ if(substr($ini_setting,0,2) == '//') continue;
+ list($key, $value) = explode('=', $ini_setting);
+ if($value){
+ $value = trim($value);
+ $key = trim($key);
+ switch (strtolower($value)) {
+ case '0':
+ // PHP-FPM might complain about invalid boolean value if you use 0
+ $value = 'off';
+ case '1':
+ case 'on':
+ case 'off':
+ case 'true':
+ case 'false':
+ case 'yes':
+ case 'no':
+ $final_php_ini_settings[] = array('ini_setting' => 'php_admin_flag['.$key.'] = '.$value);
+ break;
+ default:
+ $final_php_ini_settings[] = array('ini_setting' => 'php_admin_value['.$key.'] = '.$value);
}
+ }
}
}
}
--
Gitblit v1.9.1